ACTION_TYPE_INSERT = 1
ACTION_TYPE_UPDATE = 2
ACTION_TYPE_DELETE = 3

ACTION_TYPE_CHOICES = (
    (ACTION_TYPE_INSERT, 'insert'),
    (ACTION_TYPE_UPDATE, 'update'),
    (ACTION_TYPE_DELETE, 'delete'),
)
